#
# spec file for package libacars2
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2019-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   2
%define libname libacars-2-%{sover}
Name:           libacars2
Version:        2.2.0
Release:        1.2
Summary:        A library for decoding various ACARS message payloads
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/szpajder/libacars
#Git-Clone:     https://github.com/szpajder/libacars.git
Source:         https://github.com/szpajder/libacars/archive/v%{version}.tar.gz#/libacars-%{version}.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  cmake >= 3.1
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib) >= 1.2

%description
libacars is a library for decoding various ACARS message payloads.

%package -n %{libname}
Summary:        A library for decoding various ACARS message payloads
Group:          System/Libraries

%description -n %{libname}
libacars is a library for decoding various ACARS message payloads.

%package devel
Summary:        Development files for libacars
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libacars is a library for decoding various ACARS message payloads.

This subpackage contains libraries and header files for developing
applications that want to make use of libacars.

%package -n acars2-examples
Summary:        Example applications for libacars
Group:          Productivity/Hamradio/Other
Conflicts:      acars-examples

%description -n acars2-examples
Example applications for for libacars:

 * decode_arinc.c - decodes ARINC-622 messages supplied at the
   command line or from a file.
 * adsc_get_position - illustrates how to extract position-related
   fields from decoded ADS-C message.
 * cpdlc_get_position - illustrates how to extract position-related
   fields from CPDLC position reports.
 * media_advisory - decodes Media Advisory messages (ACARS label SA
   reports)

%prep
%setup -q -n libacars-%{version}

%build
%cmake \
    -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
    -DCMAKE_SHARED_LINKER_FLAGS=""

%install
%cmake_install
rm -rf %{buildroot}/%{_datadir}/doc

%check
%ctest

%ldconfig_scriptlets -n %{libname}

%files -n %{libname}
%doc CHANGELOG.md README.md
%license LICENSE.md
%{_libdir}/libacars-2.so.%{sover}*

%files devel
%license LICENSE.md
%doc doc/API_REFERENCE.md
%{_includedir}/libacars-2
%{_libdir}/libacars-2.so
%{_libdir}/pkgconfig/libacars-2.pc

%files -n acars2-examples
%license LICENSE.md
%{_bindir}/adsc_get_position
%{_bindir}/cpdlc_get_position
%{_bindir}/decode_acars_apps

%changelog
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.0
  * Support for decoding OHMA messages. These are diagnostic data
    exchanged with Boeing 737MAX aircraft.
    Decoding requires libacars to be built with ZLIB support.
    The data is encoded in JSON which libacars might optionally
    pretty-print, when serializing the message as text.
    Pretty-printing feature requires Jansson library.
* Mon May 29 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- update to 2.1.4:
  * portability fixes
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.3
  * Fixed incorrect calculation of reporting interval in ADS-C
    Periodic Contract Requests.
* Fri Dec  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.2
  * Fixed a build failure when compiling without libxml2 support.
* Sun Nov 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.1
  * Media Advisory: fixed a bug where a message with 10 or more
    available link indicators could overflow the static buffer
    and produce garbled result.
  * Media Advisory: fixed a bug where a message with an
    exceptionally long text field could cause buffer overrun and
    crash the program.
  * Media Advisory: replaced message parsing routine with a
    simpler and more robust one.
* Sat Nov  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.0
  * ADS-C: fixed incorrect computation of vertical speed threshold
    in contract request messages.
  * JSON: fixed a bug where an ASN.1 string containing a
    \0 character caused truncation of JSON output. NULLs in strings
    are now replaced with \u0000 sequence.
  * JSON: ASN.1 SEQUENCEs are now printed as JSON objects rather
    than arrays of objects. It produces a simpler and more readable
    JSON structure. The change applies to all ASN.1 types formatted
    with la_asn1_format_SEQUENCE_cpdlc_as_json function. Refer to
    asn1-format-cpdlc-json.c file for a full list.
  * JSON: added json_append_octet_string_as_string function which
    prints the contents of the given byte buffer as a JSON string
    rather than as a list of numeric values.
  * JSON: added a bunch of new functions for formatting basic
    ASN.1 types. Now we have them all in libacars. Before that
    they were scattered between libacars and dumpvdl2.
  * JSON: deprecate la_json_append_long function. A more portable
    version named la_json_append_int64 shall be used instead.
  * Small bugfixes, code cleanups.
* Mon Aug 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.1
  * Fixed a bug causing FANS1/A ErrorInformation message elements
    to be decoded incorrectly.
* Tue Apr  7 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Rename acars-examples to acars2-examples, conflicting with
  acars-examples: this package was duplicate generated between
  libacars and libacars2, with a random one being published in the
  repositories.
* Sun Jan 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.0
  New major release 2.
  * API and ABI are not backwards compatible with version 1
  * New feature: generic engine for reassembly of fragmented
    messages. Supports automatic tracking of fragments' sequence
    numbers (with possible wraparounds), handles reassembly
    timeouts and fragment deduplication. Messages can be keyed
    with arbitrary data (eg. custom header fields).
  * New feature: automatic reassembly of ACARS messages.
  * New feature: automatic reassembly of MIAM file transfers.
  * New feature: pretty-printing of XML text in ACARS and MIAM CORE
    payloads.
  * New feature: simple hash table implementation.
  * Incompatible change: new library configuration API. la_config
    structure with static fields has been removed. Configuration
    variables are now stored in a hash table, read with
    la_config_get_* and set with la_config_set_* functions. Refer
    to doc/API_REFERENCE.md for details.
    Refer to libacars/config_defaults.h for the most current list of
    configuration options and their default values.
  * Incompatible change: ACARS parser now strips sublabel and MFI
    (Message Function Identifier) fields from the message text, if
    present. Their values are stored in la_acars_msg structure in
    sublabel and mfi fields. In text and JSON output they are
    printed as separate fields.
  * Incompatible change: MIAM parser and ARINC-622 ATS message
    parser now expect sublabel and MFI fields to be stripped by the
    caller, otherwise the parser will ignore the message. This
    operation can be performed with minimal fuss using
    la_acars_extract_sublabel_and_mfi function.
  * Incompatible change: la_miam_parse function prototype has
    changed. All parameters except txt (message text) have been
    removed.
  * Incompatible change: no field of la_acars_msg structure has
    been removed.
  * Incompatible change: Media Advisory message timestamp and
    version are now stored as numbers, not characters. Type of
    hour, minute, second and version fields in
    la_media_adv_msg structure has been changed from char[] to
    uint8_t. Relevant JSON keys have changed types as well.
  * Incompatible change: state and current_link fields in
    la_media_adv_msg structure changed from char[2] to char, hence
    their values are no longer NULL-terminated.
  * examples: media_advisory app has been removed.
    Use decode_acars_apps instead.
  * Bugfixes, code cleanups.
* Wed Feb 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.0
  * Added support for decoding Media Independent Aircraft Messaging
    (MIAM - ACARS label MA) version 1 and 2. All types of MIAM
    frames are decoded, provided that they fit in a single ACARS
    message. In case of multi-fragment MIAM messages only the first
    fragment is decoded (partially) due to lack of message
    reassembly support in libacars. This will be addressed in a
    future release.
    MIAM uses DEFLATE compression, hence libacars now optionally
    depends on zlib.  If zlib is not available at the build stage,
    MIAM decompression code will be disabled and many messages
    will be left undecoded.
  * `decode_acars_apps` is a new example application. It decodes
    all ACARS applications supported by libacars. This makes
    `decode_arinc` application obsolete
  * Minor bugfixes in the build system.
- Remove patch:
  * libacars-libsuffix.patch
* Sat Jan 19 2019 mardnh@gmx.de
- Initial package, version 1.1.0
